@@ -1,4 +1,5 @@
 import numpy as np
+import pandas as pd
 import pint
 import pytest
 import xarray as xr
@@ -10,7 +11,6 @@ from .utils import (
     assert_equal,
     assert_identical,
     assert_units_equal,
-    raises_regex,
     requires_bottleneck,
     requires_dask_array,
     requires_scipy,
@@ -110,10 +110,62 @@ class TestQuantifyDataArray:
         with pytest.raises(AttributeError):
             result["u"].data.units
 
-    def test_error_when_already_units(self, example_quantity_da):
+    def test_error_when_changing_units(self, example_quantity_da):
         da = example_quantity_da
-        with raises_regex(ValueError, "already has units"):
-            da.pint.quantify()
+        with pytest.raises(ValueError, match="already has units"):
+            da.pint.quantify("s")
+
+    def test_attach_no_units(self):
+        arr = xr.DataArray([1, 2, 3], dims="x")
+        quantified = arr.pint.quantify()
+        assert_identical(quantified, arr)
+        assert_units_equal(quantified, arr)
+
+    def test_attach_no_new_units(self):
+        da = xr.DataArray(unit_registry.Quantity([1, 2, 3], "m"), dims="x")
+        quantified = da.pint.quantify()
+        assert_identical(quantified, da)
+        assert_units_equal(quantified, da)
+
+    def test_attach_same_units(self):
+        da = xr.DataArray(unit_registry.Quantity([1, 2, 3], "m"), dims="x")
+        quantified = da.pint.quantify("m")
+        assert_identical(quantified, da)
+        assert_units_equal(quantified, da)
+
+    def test_error_when_changing_units_dimension_coordinates(self):
+        arr = xr.DataArray(
+            [1, 2, 3],
+            dims="x",
+            coords={"x": ("x", [-1, 0, 1], {"units": unit_registry.Unit("m")})},
+        )
+        with pytest.raises(ValueError, match="already has units"):
+            arr.pint.quantify({"x": "s"})
+
+    def test_dimension_coordinate_array(self):
+        ds = xr.Dataset(coords={"x": ("x", [10], {"units": "m"})})
+        arr = ds.x
+
+        # does not actually quantify because `arr` wraps a IndexVariable
+        # but we still get a `Unit` in the attrs
+        q = arr.pint.quantify()
+        assert isinstance(q.attrs["units"], Unit)
+
+    def test_dimension_coordinate_array_already_quantified(self):
+        ds = xr.Dataset(coords={"x": ("x", [10], {"units": unit_registry.Unit("m")})})
+        arr = ds.x
+
+        with pytest.raises(ValueError):
+            arr.pint.quantify({"x": "s"})
+
+    def test_dimension_coordinate_array_already_quantified_same_units(self):
+        ds = xr.Dataset(coords={"x": ("x", [10], {"units": unit_registry.Unit("m")})})
+        arr = ds.x
+
+        quantified = arr.pint.quantify({"x": "m"})
+
+        assert_identical(quantified, arr)
+        assert_units_equal(quantified, arr)
 
     def test_error_on_nonsense_units(self, example_unitless_da):
         da = example_unitless_da
@@ -136,9 +188,9 @@ class TestQuantifyDataArray:
 
 
 @pytest.mark.parametrize("formatter", ("", "P", "C"))
-@pytest.mark.parametrize("flags", ("", "~", "#", "~#"))
-def test_units_to_str_or_none(formatter, flags):
-    unit_format = f"{{:{flags}{formatter}}}"
+@pytest.mark.parametrize("modifier", ("", "~"))
+def test_units_to_str_or_none(formatter, modifier):
+    unit_format = f"{{:{modifier}{formatter}}}"
     unit_attrs = {None: "m", "a": "s", "b": "degC", "c": "degF", "d": "degK"}
     units = {key: unit_registry.Unit(value) for key, value in unit_attrs.items()}
 
@@ -174,6 +226,17 @@ class TestDequantifyDataArray:
         result = quantified.pint.dequantify()
         assert_equal(result, orig)
 
+    def test_multiindex(self):
+        mindex = pd.MultiIndex.from_product([["a", "b"], [1, 2]], names=("lat", "lon"))
+
+        da = xr.DataArray(
+            np.arange(len(mindex)), dims="multi", coords={"multi": mindex}
+        )
+        result = da.pint.dequantify()
+
+        xr.testing.assert_identical(da, result)
+        assert isinstance(result.indexes["multi"], pd.MultiIndex)
+
 
 class TestPropertiesDataArray:
     def test_magnitude_getattr(self, example_quantity_da):
@@ -280,8 +343,35 @@ class TestQuantifyDataSet:
         )
 
     def test_error_when_already_units(self, example_quantity_ds):
-        with raises_regex(ValueError, "already has units"):
-            example_quantity_ds.pint.quantify({"funds": "pounds"})
+        with pytest.raises(ValueError, match="already has units"):
+            example_quantity_ds.pint.quantify({"funds": "kg"})
+
+    def test_attach_no_units(self):
+        ds = xr.Dataset({"a": ("x", [1, 2, 3])})
+        quantified = ds.pint.quantify()
+        assert_identical(quantified, ds)
+        assert_units_equal(quantified, ds)
+
+    def test_attach_no_new_units(self):
+        ds = xr.Dataset({"a": ("x", unit_registry.Quantity([1, 2, 3], "m"))})
+        quantified = ds.pint.quantify()
+
+        assert_identical(quantified, ds)
+        assert_units_equal(quantified, ds)
+
+    def test_attach_same_units(self):
+        ds = xr.Dataset({"a": ("x", unit_registry.Quantity([1, 2, 3], "m"))})
+        quantified = ds.pint.quantify({"a": "m"})
+
+        assert_identical(quantified, ds)
+        assert_units_equal(quantified, ds)
+
+    def test_error_when_changing_units_dimension_coordinates(self):
+        ds = xr.Dataset(
+            coords={"x": ("x", [-1, 0, 1], {"units": unit_registry.Unit("m")})},
+        )
+        with pytest.raises(ValueError, match="already has units"):
+            ds.pint.quantify({"x": "s"})
 
     def test_error_on_nonsense_units(self, example_unitless_ds):
         ds = example_unitless_ds
@@ -301,6 +391,20 @@ class TestQuantifyDataSet:
         with pytest.raises(ValueError, match="'users'"):
             ds.pint.quantify(units={"users": "aecjhbav"})
 
+    def test_existing_units(self, example_quantity_ds):
+        ds = example_quantity_ds.copy()
+        ds.t.attrs["units"] = unit_registry.Unit("m")
+
+        with pytest.raises(ValueError, match="Cannot attach"):
+            ds.pint.quantify({"funds": "kg"})
+
+    def test_existing_units_dimension(self, example_quantity_ds):
+        ds = example_quantity_ds.copy()
+        ds.t.attrs["units"] = unit_registry.Unit("m")
+
+        with pytest.raises(ValueError, match="Cannot attach"):
+            ds.pint.quantify({"t": "s"})
+
 
 class TestDequantifyDataSet:
     def test_strip_units(self, example_quantity_ds):
@@ -1080,18 +1184,6 @@ def test_chunk(obj):
             ValueError,
             id="Dataset-incompatible units",
         ),
-        pytest.param(
-            xr.Dataset(
-                {
-                    "a": ("x", [10, 20, 30], {"units": unit_registry.Unit("dm")}),
-                    "b": ("y", [60, 120], {"units": unit_registry.Unit("s")}),
-                }
-            ),
-            {"a": Quantity([1, 3], "s"), "b": Quantity([1], "m")},
-            None,
-            ValueError,
-            id="Dataset-incompatible units-invalid dims",
-        ),
         pytest.param(
             xr.DataArray(
                 [[0, 1], [2, 3], [4, 5]],
@@ -1148,20 +1240,6 @@ def test_chunk(obj):
             ValueError,
             id="DataArray-incompatible units",
         ),
-        pytest.param(
-            xr.DataArray(
-                [[0, 1], [2, 3], [4, 5]],
-                dims=("x", "y"),
-                coords={
-                    "x": ("x", [10, 20, 30], {"units": unit_registry.Unit("dm")}),
-                    "y": ("y", [60, 120], {"units": unit_registry.Unit("s")}),
-                },
-            ),
-            {"x": Quantity([10, 30], "s"), "y": Quantity([60], "m")},
-            None,
-            ValueError,
-            id="DataArray-incompatible units-invalid dims",
-        ),
     ),
 )
 def test_reindex(obj, indexers, expected, error):
@@ -1371,18 +1449,6 @@ def test_reindex_like(obj, other, expected, error):
             ValueError,
             id="Dataset-incompatible units",
         ),
-        pytest.param(
-            xr.Dataset(
-                {
-                    "a": ("x", [10, 20, 30], {"units": unit_registry.Unit("dm")}),
-                    "b": ("y", [60, 120], {"units": unit_registry.Unit("s")}),
-                }
-            ),
-            {"a": Quantity([1, 3], "s"), "b": Quantity([1], "m")},
-            None,
-            ValueError,
-            id="Dataset-incompatible units-invalid dims",
-        ),
         pytest.param(
             xr.Dataset(
                 {
@@ -1485,20 +1551,6 @@ def test_reindex_like(obj, other, expected, error):
             None,
             id="DataArray-data units",
         ),
-        pytest.param(
-            xr.DataArray(
-                [[0, 1], [2, 3], [4, 5]],
-                dims=("x", "y"),
-                coords={
-                    "x": ("x", [10, 20, 30], {"units": unit_registry.Unit("dm")}),
-                    "y": ("y", [60, 120], {"units": unit_registry.Unit("s")}),
-                },
-            ),
-            {"x": Quantity([10, 30], "s"), "y": Quantity([60], "m")},
-            None,
-            ValueError,
-            id="DataArray-incompatible units-invalid dims",
-        ),
     ),
 )
 def test_interp(obj, indexers, expected, error):
