@@ -482,6 +482,11 @@ class TestXarrayFunctions:
                 {"a": "K", "b": "hPa", "x": "m", "u": "s"},
                 id="Dataset",
             ),
+            pytest.param(
+                Dataset(coords={"t": ("t", [], {"units": "seconds since 2000-01-01"})}),
+                {},
+                id="datetime_unit",
+            ),
         ),
     )
     def test_extract_unit_attributes(self, obj, expected):
@@ -546,6 +551,11 @@ class TestXarrayFunctions:
                 {"a": "K", "b": "hPa", "x": "m", "u": "s"},
                 id="Dataset",
             ),
+            pytest.param(
+                Dataset(coords={"t": ("t", [], {"units": "seconds since 2000-01-01"})}),
+                {},
+                id="datetime_unit",
+            ),
         ),
     )
     def test_strip_unit_attributes(self, obj, expected):
